// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
// SPDX-License-Identifier: BSD-3-Clause
#include "vtkCellGridGS_DGTet.h"

const char *vtkCellGridGS_DGTet =
"//VTK::System::Dec\n"
"\n"
"// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen\n"
"// SPDX-License-Identifier: BSD-3-Clause\n"
"// Template for the cellgrid mapper geometry shader\n"
"\n"
"// look up cell points, types and vertex positions from texture buffers.\n"
"uniform isamplerBuffer cellConnectivity;\n"
"uniform isamplerBuffer sideConnectivity;\n"
"uniform isamplerBuffer faceConnectivity;\n"
"uniform samplerBuffer cellParametrics;\n"
"uniform samplerBuffer vertexPositions;\n"
"\n"
"// vtkActor may be given custom uniforms.\n"
"//VTK::CustomUniforms::Dec\n"
"\n"
"// camera and actor matrix values\n"
"//VTK::Camera::Dec\n"
"\n"
"// Position of vertex in view coordinates.\n"
"//VTK::PositionVC::Dec\n"
"\n"
"// Color output per vertex in the rendered primitives.\n"
"//VTK::Color::Dec\n"
"\n"
"// The normal of the output primitive in view coordinates.\n"
"//VTK::Normal::Dec\n"
"\n"
"layout(points) in;\n"
"layout(triangle_strip, max_vertices = 6) out; // TODO: use string substitution for this\n"
"\n"
"// Input from vertex shader\n"
"in int vtkCellSideId[]; // size 1\n"
"\n"
"// send cell ID to fragment shader\n"
"flat out int vtkCellIdGSOutput;\n"
"\n"
"// Custom output for fragment shader\n"
"out vec3 pCoordGSOutput;\n"
"\n"
"//----------------------------------------------------------------\n"
"vec3 ComputeNormal(in vec3 p1, in vec3 p2, in vec3 p3)\n"
"{\n"
"  vec3 delta32 = p3 - p2;\n"
"  vec3 delta12 = p1 - p2;\n"
"  return cross(delta32, delta12);\n"
"}\n"
"\n"
"//----------------------------------------------------------------\n"
"/**\n"
" * Draws a triangle for the sideId'th face of a linear tetrahedron.\n"
" * sideId - index of the face which will be rendered as a triangle - [0, 3].\n"
" * cellId - index of the vtk cell whose faces we shall render - [0, numCells[.\n"
" */\n"
"void DrawTetFace(in int sideId, in int cellId)\n"
"{\n"
"  int cellLocalPtIds[3], cellGlobalPtIds[3];\n"
"  vec3 coords[3];\n"
"  for (int i = 0; i < 3; ++i)\n"
"  {\n"
"    cellLocalPtIds[i] = texelFetch(faceConnectivity, sideId * 3 + i).r;\n"
"    cellGlobalPtIds[i] = texelFetch(cellConnectivity, cellId * 4 + cellLocalPtIds[i]).r;\n"
"    coords[i] = texelFetch(vertexPositions, cellGlobalPtIds[i]).xyz;\n"
"  }\n"
"\n"
"  vec3 n = ComputeNormal(coords[0], coords[1], coords[2]);\n"
"  if (length(n) == 0.0)\n"
"  {\n"
"    n.z = 1.0f;\n"
"  }\n"
"\n"
"  //VTK::Normal::Impl\n"
"\n"
"  for (int ii = 0; ii < 3; ++ii)\n"
"  {\n"
"    int localPtId = cellLocalPtIds[ii];\n"
"    int globalPtId = cellGlobalPtIds[ii];\n"
"\n"
"    vec4 vertexMC = vec4(texelFetch(vertexPositions, globalPtId).xyz, 1.0f);\n"
"\n"
"    //VTK::PositionVC::Impl\n"
"\n"
"    //VTK::Color::Impl\n"
"\n"
"    pCoordGSOutput = texelFetch(cellParametrics, localPtId).xyz;\n"
"    EmitVertex();\n"
"  }\n"
"  EndPrimitive();\n"
"}\n"
"\n"
"//----------------------------------------------------------------\n"
"void main()\n"
"{\n"
"  int cellId = texelFetch(sideConnectivity, 2 * vtkCellSideId[0]).r;\n"
"  int sideId = texelFetch(sideConnectivity, 2 * vtkCellSideId[0] + 1).r;\n"
"  vtkCellIdGSOutput = cellId;\n"
"  DrawTetFace(sideId, cellId);\n"
"}\n"
"";
